@@ -319,7 +319,7 @@ json_scanner_input_text (JsonScanner *scanner,
   scanner->next_token = JSON_TOKEN_NONE;
 
   scanner->text = text;
-  scanner->text_end = text + text_len;
+  scanner->text_end = text != NULL ? text + text_len : 0;
 
   g_clear_pointer (&scanner->buffer, g_free);
 }
@@ -457,7 +457,8 @@ json_scanner_unexp_token (JsonScanner  *scanner,
 	    g_snprintf (token_string, token_string_len, "character `\\%o'", scanner->token);
 	  break;
 	}
-      /* fall through */
+      G_GNUC_FALLTHROUGH;
+
     case JSON_TOKEN_SYMBOL:
       if (expected_token == JSON_TOKEN_SYMBOL || expected_token > JSON_TOKEN_LAST)
 	print_unexp = false;
@@ -593,7 +594,8 @@ json_scanner_unexp_token (JsonScanner  *scanner,
 	    g_snprintf (expected_string, expected_string_len, "character `\\%o'", expected_token);
 	  break;
 	}
-      /* fall through */
+      G_GNUC_FALLTHROUGH;
+
     case JSON_TOKEN_SYMBOL:
       {
         bool need_valid = (scanner->token == JSON_TOKEN_SYMBOL || scanner->token > JSON_TOKEN_LAST);
@@ -889,6 +891,7 @@ json_scanner_get_token_ll (JsonScanner    *scanner,
 			  break;
 
                         case 'u':
+                        {
                           guint fchar = json_scanner_peek_next_char (scanner);
                           if (is_hex_digit (fchar))
                             {
@@ -920,7 +923,7 @@ json_scanner_get_token_ll (JsonScanner    *scanner,
                                       break;
                                     }
                                   else
-                                    ch = json_scanner_get_char (scanner, line_p, position_p);
+                                    json_scanner_get_char (scanner, line_p, position_p);
 
                                   next_ch = json_scanner_peek_next_char (scanner);
                                   if (next_ch != 'u')
@@ -932,7 +935,7 @@ json_scanner_get_token_ll (JsonScanner    *scanner,
                                       break;
                                     }
                                   else
-                                    ch = json_scanner_get_char (scanner, line_p, position_p);
+                                    json_scanner_get_char (scanner, line_p, position_p);
 
                                   /* read next surrogate */
                                   gunichar units[2];
@@ -994,7 +997,8 @@ json_scanner_get_token_ll (JsonScanner    *scanner,
                               gstring = NULL;
                             }
                           break;
-			  
+                        }
+
 			default:
                           token = JSON_TOKEN_ERROR;
                           value.v_error = JSON_ERROR_TYPE_UNESCAPED_CTRL;
@@ -1027,7 +1031,7 @@ json_scanner_get_token_ll (JsonScanner    *scanner,
               ch = 0;
               break;
             }
-            G_GNUC_FALLTHROUGH;
+          G_GNUC_FALLTHROUGH;
 
 	case '0':
 	case '1':
