@@ -1,7 +1,9 @@
 /* json-gobject.c - JSON GObject integration
  * 
  * This file is part of JSON-GLib
- * Copyright (C) 2007  OpenedHand Ltd.
+ *
+ * SPDX-FileCopyrightText: 2007  OpenedHand Ltd.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -86,6 +88,9 @@ json_serializable_serialize_property (JsonSerializable *serializable,
  *   property description (since JSON-GLib 1.6)
  * - a `GValue` initialized with the expected type of the property
  *
+ * This function will not be called for properties that are marked as
+ * as `G_PARAM_CONSTRUCT_ONLY`.
+ *
  * Returns: `TRUE` if the property was successfully deserialized
  */
 gboolean
@@ -113,8 +118,8 @@ json_serializable_deserialize_property (JsonSerializable *serializable,
 }
 
 static gboolean
-json_serializable_real_deserialize (JsonSerializable *serializable,
-                                    const gchar      *name,
+json_serializable_real_deserialize (JsonSerializable *serializable G_GNUC_UNUSED,
+                                    const gchar      *name G_GNUC_UNUSED,
                                     GValue           *value,
                                     GParamSpec       *pspec,
                                     JsonNode         *node)
@@ -128,8 +133,8 @@ json_serializable_real_deserialize (JsonSerializable *serializable,
 }
 
 static JsonNode *
-json_serializable_real_serialize (JsonSerializable *serializable,
-                                  const gchar      *name,
+json_serializable_real_serialize (JsonSerializable *serializable G_GNUC_UNUSED,
+                                  const gchar      *name G_GNUC_UNUSED,
                                   const GValue     *value,
                                   GParamSpec       *pspec)
 {
